@@ -1,6 +1,6 @@
 /* Xsynth DSSI software synthesizer GUI
  *
- * Copyright (C) 2004, 2009 Sean Bolton and others.
+ * Copyright (C) 2004, 2009, 2010 Sean Bolton and others.
  *
  * Portions of this file may have come from Chris Cannam and Steve
  * Harris's public domain DSSI example code.
@@ -296,10 +296,9 @@ main(int argc, char *argv[])
 #endif
     /* { int i; fprintf(stderr, "args:\n"); for(i=0; i<argc; i++) printf("%d: %s\n", i, argv[i]); } // debug */
     
-    gtk_set_locale();
     gtk_init(&argc, &argv);
 
-    if (!strcmp(argv[1], "-test")) {
+    if (argc > 1 && !strcmp(argv[1], "-test")) {
         gui_test_mode = 1;
         test_argv[0] = argv[0];
         test_argv[1] = "osc.udp://localhost:9/test/mode";
